translate.convert.mozlang2po

Package translate :: Package convert :: Module mozlang2po |
[hide private]
[frames] | no frames]

# Module mozlang2po

source code

convert Java/Mozilla .properties files to Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/prop2po for examples and usage instructions

Classes | [hide private]
| lang2po

Functions | [hide private]
convertlang(inputfile, outputfile, templates, duplicatestyle="msgctxt", encoding="utf-8") reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Variables | [hide private]
| formats = `{"lang":("po", convertlang)}`

Imports: lang, po